// Original code by steje, updated by wowbagger.
// Enables\Disables folder size calculation feature based on a variable specific to a tab. 

// Original
//   OnAfterFolderChange_smartgetsizes:
//   Revision: v1.0.7 (js)
//   (c) 2014 steje
//
// This is a script for written for Directory Opus v11.
// See http://www.gpsoft.com.au/redirect.asp?page=scripts for development information.

// Called by Directory Opus to initialize the script
function OnInit(initData)
{
  // Provide basic information about the Script
  initData.name = "Folder Size calculation modifications";
  initData.desc = "Check for lister variable on folder changes to auto-calculate folder sizes or not.";
  initData.copyright = "(c) 2014 steje, modified by wowbagger";
  initData.version = "v1.0.7b.2 (js)";
  initData.default_enable = true;
  
  // Set DEBUG flag below to true in order to enable logging messages to the Opus Output Window
  initData.config.DEBUG = false;
  initData.config.CALCFOLDERSIZES_on_value = "all";
 
  // Initialise the command that this script adds
  var cmd = initData.AddCommand();
  cmd.name = "SmartCalcFolderSizes";
  cmd.icon = "getsizes";
  cmd.method = "OnSmartCalcFolderSizes";
  cmd.desc = "Enables\Disables the folder size calculation feature based on a variable.";
  cmd.label = "Smart Calc Folder Sizes";
   
  return false;
}

// Implement the SmartGetSizes command
function OnSmartCalcFolderSizes(commandData)
{
  logMsg("OnSmartCalcFolderSizes running");
  SmartGetSizes();
}

function OnSourceDestChange(SourceDestData)
{
  if(SourceDestData.source)
  {
    logMsg("OnSourceDestChange running source:" + SourceDestData.source + " dest:" + SourceDestData.dest + " tab[" + SourceDestData.tab + "]:" + SourceDestData.tab.Path);
    SmartGetSizes();
  }
}

function OnActivateTab(ActivateTabData)
{
  logMsg("OnActivateTab running old:" + ActivateTabData.old.Path);
  SmartGetSizes();
}

// Called whenever the folder is changed
function OnAfterFolderChange(afterFolderChangeData)
{
  logMsg("OnAfterFolderChange running");
  SmartGetSizes();
}

function SmartGetSizes()
{
  var tab = DOpus.listers(0).activetab;
  logMsg("SmartGetSizes! tab[" + tab + "]:" + tab.path);
 
  var objCmd = DOpus.CreateCommand;
  if (objCmd.IsSet("$lst:autosize"))
  {
    logMsg("The 'autosize' lister variable is set!");
    objCmd.RunCommand("Set CALCFOLDERSIZES="+ Script.config.CALCFOLDERSIZES_on_value);
  }
  else if (objCmd.IsSet("$src:autosize"))
  {
    logMsg("The 'autosize' sourcetab variable is set!");
    objCmd.RunCommand("Set CALCFOLDERSIZES="+ Script.config.CALCFOLDERSIZES_on_value);
  }
  else
  {
    logMsg("The 'autosize' variable is NOT set!");
    objCmd.RunCommand("Set CALCFOLDERSIZES=off");
  }
  objCmd.UpdateToggle();
  delete objCmd;
}
 
function IsDebugEnabled()
{
  var objCmd = DOpus.CreateCommand;
  return (Script && Script.config.DEBUG) || objCmd.IsSet("$glob:debug");
}

// Subroutine to allow toggling of the global DEBUG variable to control whether logging is performed or not
function logMsg(message)
{
   if (IsDebugEnabled()) DOpus.Output(message);
   return;
}
